# PS-Lite Documents

PS-Lite is a lightweight implementation of the parameter server.  It provides
asynchronous and zero-copy key-value pair communications between machines.


```eval_rst
.. toctree::
   :numbered:

   overview
   get_started
   tutorials
   how_to
   api
```
